@@ -68,7 +68,7 @@ class LambdaHandler(BaseHandler):
             postdata=postdata,
             response=response,
             session=self.session,
-            log=lambda message, function=None: self.log(tx, message, function),
+            log=lambda message, function=None: self.log(message, function),
         )
 
         # Determine action from postdata or query parameters
@@ -83,7 +83,7 @@ class LambdaHandler(BaseHandler):
         except Exception as e:
             self.handle_error(tx, local_context, e)
             
-        return local_context.response.render()
+        return local_context.response().render()
 
     def track(self, tx, data={}, user=None):
         data = data.copy()
