@@ -162,7 +162,7 @@ class Table:
                 }
 
             if isinstance(columns, str):
-                columns = [columns]
+                columns = columns.split(",")
 
             if not columns:
                 raise ValueError("Index columns cannot be empty")
