@@ -485,7 +485,9 @@ END;
         return "\n".join(statements), tuple()
 
     @classmethod
-    def ensure_sys_modified_count(cls, name, has_column=False):
+    def ensure_sys_modified_count(
+        cls, name, has_column=False, has_row_column=False
+    ):
         """Ensure sys_modified_count exists for SQL Server tables along with maintenance triggers."""
         if "." in name:
             schema, table_name = name.split(".", 1)
